@@ -17,6 +17,7 @@
 package org.drools.workbench.screens.scenariosimulation.client.rightpanel;
 
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 
 import javax.enterprise.context.Dependent;
@@ -35,13 +36,12 @@ public class FieldItemPresenter implements FieldItemView.Presenter {
 
     protected Map<String, FieldItemView> fieldItemMap = new HashMap<>();
 
-
     @Override
-    public LIElement getLIElement(String parentPath, String factName, String fieldName, String className) {
-        String key = parentPath  + "." + fieldName;
+    public LIElement getLIElement(List<String> parentPath, String factName, String fieldName, String className, String classTypeName) {
+        String key = String.join(".", parentPath)  + "." + fieldName;
         if (!fieldItemMap.containsKey(key)) {
             FieldItemView fieldItemView = viewsProvider.getFieldItemView();
-            fieldItemView.setFieldData(parentPath, factName, fieldName, className);
+            fieldItemView.setFieldData(parentPath, factName, fieldName, className, classTypeName);
             fieldItemView.setPresenter(this);
             fieldItemMap.put(key, fieldItemView);
         }
@@ -67,4 +67,9 @@ public class FieldItemPresenter implements FieldItemView.Presenter {
     public void showAll() {
         fieldItemMap.values().forEach(FieldItemView::show);
     }
+
+    @Override
+    public void reset() {
+        fieldItemMap.clear();
+    }
 }
