@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -17,6 +17,7 @@ package org.drools.workbench.screens.testscenario.client;
 
 import java.util.Collection;
 import java.util.List;
+
 import javax.inject.Inject;
 
 import com.google.gwt.core.client.GWT;
@@ -36,7 +37,6 @@ import org.jboss.errai.common.client.api.Caller;
 import org.kie.workbench.common.services.shared.rulename.RuleNamesService;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.uberfire.backend.vfs.Path;
-import org.uberfire.ext.widgets.common.client.common.SmallLabel;
 import org.uberfire.ext.widgets.common.client.common.popups.errors.ErrorPopup;
 
 public class ScenarioWidgetComponentCreator {
@@ -60,10 +60,10 @@ public class ScenarioWidgetComponentCreator {
         this.ruleNamesService = ruleNamesService;
     }
 
-    protected void reset(final ScenarioParentWidget scenarioWidget,
-                         final Path path,
-                         final AsyncPackageDataModelOracle oracle,
-                         final Scenario scenario) {
+    public void reset(final ScenarioParentWidget scenarioWidget,
+                      final Path path,
+                      final AsyncPackageDataModelOracle oracle,
+                      final Scenario scenario) {
         this.scenarioWidget = scenarioWidget;
         this.oracle = oracle;
         this.scenario = scenario;
@@ -98,22 +98,10 @@ public class ScenarioWidgetComponentCreator {
                                this.scenarioWidget);
     }
 
-    protected HorizontalPanel createHorizontalPanel() {
-        HorizontalPanel h = new HorizontalPanel();
-        h.add(new GlobalButton(getScenario(),
-                               this.scenarioWidget,
-                               oracle));
-        h.add(new SmallLabel(TestScenarioConstants.INSTANCE.globals()));
-        return h;
-    }
-
-    protected SmallLabel createSmallLabel() {
-        return new SmallLabel(TestScenarioConstants.INSTANCE.configuration());
-    }
-
-    protected ConfigWidget createConfigWidget() {
-        return new ConfigWidget(getScenario(),
-                                this);
+    protected GlobalButton createGlobalButton() {
+        return new GlobalButton(getScenario(),
+                                this.scenarioWidget,
+                                oracle);
     }
 
     protected AddExecuteButton createAddExecuteButton() {
@@ -138,29 +126,24 @@ public class ScenarioWidgetComponentCreator {
                                     oracle);
     }
 
-    protected CallMethodLabelButton createCallMethodLabelButton(final List<ExecutionTrace> listExecutionTrace,
-                                                                final int executionTraceLine,
-                                                                final ExecutionTrace previousExecutionTrace) {
-        return new CallMethodLabelButton(previousExecutionTrace,
-                                         getScenario(),
-                                         listExecutionTrace.get(executionTraceLine),
-                                         this.scenarioWidget,
-                                         oracle);
+    protected CallMethodOnNewDataButton createCallMethodLabelButton(final List<ExecutionTrace> listExecutionTrace,
+                                                                    final int executionTraceLine,
+                                                                    final ExecutionTrace previousExecutionTrace) {
+        return new CallMethodOnNewDataButton(previousExecutionTrace,
+                                             getScenario(),
+                                             listExecutionTrace.get(executionTraceLine),
+                                             this.scenarioWidget,
+                                             oracle);
     }
 
-    protected GivenLabelButton createGivenLabelButton(final List<ExecutionTrace> listExecutionTrace,
-                                                      final int executionTraceLine,
-                                                      final ExecutionTrace previousExecutionTrace) {
-        return new GivenLabelButton(previousExecutionTrace,
-                                    getScenario(),
-                                    listExecutionTrace.get(executionTraceLine),
-                                    this.scenarioWidget,
-                                    oracle);
-    }
-
-    protected ExecutionWidget createExecutionWidget(final ExecutionTrace currentExecutionTrace) {
-        return new ExecutionWidget(currentExecutionTrace,
-                                   isShowResults());
+    protected GivenButton createGivenLabelButton(final List<ExecutionTrace> listExecutionTrace,
+                                                 final int executionTraceLine,
+                                                 final ExecutionTrace previousExecutionTrace) {
+        return new GivenButton(previousExecutionTrace,
+                               getScenario(),
+                               listExecutionTrace.get(executionTraceLine),
+                               this.scenarioWidget,
+                               oracle);
     }
 
     protected ExpectPanel createExpectPanel(final ExecutionTrace currentExecutionTrace) {
